""" Represents a Single Juju machine UI widget
"""

from urwid import WidgetWrap, Text


class MachineWidget(WidgetWrap):
    def __init__(self, machine):
        """ Init

        Params:
        machine: Juju Machine Class (see https://git.io/vg0Xe)
        """
        self.machine = machine
        _attrs = ['machine_id',
                  'cpu_cores',
                  'storage',
                  'mem',
                  'agent',
                  'agent_state',
                  'agent_state_info',
                  'agent_version',
                  'dns_name',
                  'err',
                  'has_vote',
                  'wants_vote']
        for m in _attrs:
            setattr(self, m, Text(str(self.machine.get(m))))



from __future__ import unicode_literals

from urwid import (Columns, ListBox, Divider)
from ubuntui.utils import Color


class Table:
    def __init__(self):
        self._rows = []
        self._row_id = []

    def addHeadings(self, headings):
        """ Takes list of headings and converts them to column header
        with appropriate color

        Params:
        headings: List of column text headings
        """
        cols = []
        for h in headings:
            h = Color.column_header(h)
            cols.append(h)
        self.addRow(Columns(cols))

    def addColumns(self, row_id, columns):
        """ Convert list of widgets to Columns and add to a table row

        Arguments:
        row_id: unique id of new row
        columns: list of columns
        """
        if row_id not in self._row_id:
            self._row_id.append(row_id)
            self.addRow(Columns(columns))

    def addRow(self, item):
        """ Appends widget to Pile
        """
        self._rows.append(item)
        self._rows.append(
            Divider("\N{BOX DRAWINGS LIGHT HORIZONTAL}"))

    def render(self):
        return ListBox(self._rows)



""" Represents a Single Juju service UI widget
"""

from urwid import WidgetWrap, Text


class UnitWidget(WidgetWrap):
    def __init__(self, service):
        """ Init

        Params:
        machine: Juju Service Class
        """
        self.service = service
        _attrs = ['service_name',
                  'charm',
                  'exposed',
                  'networks',
                  'life']
        for m in _attrs:
            setattr(self, m, Text(str(self.service.get(m))))



""" Represents a Single Juju unit UI widget
"""

from urwid import WidgetWrap, Text


class UnitWidget(WidgetWrap):
    def __init__(self, unit):
        """ Init

        Params:
        machine: Juju Unit Class
        """
        self.unit = unit
        _attrs = ['unit_name',
                  'workload_state',
                  'extended_agent_state',
                  'workload_info',
                  'machine_id',
                  'public_address',
                  'agent_state_info']
        for m in _attrs:
            setattr(self, m, Text(getattr(self.unit, m)))
